/* --------------------------------------------------------------------------
$Id: hllist.c,v 1.2 2004/03/18 11:52:22 ahenja Exp $
Program:    	hllist

Description:    Main program for listing all the nodes in an HDF5 file.

Author(s):      Anders Henja

Copyright:	Swedish Meteorological and Hydrological Institute, 2000

History:
$Log: hllist.c,v $
Revision 1.2  2004/03/18 11:52:22  ahenja
Modifed with support for szip

Revision 1.1.1.1  2001/12/14 12:02:46  ahenja
First CVS version of hlhdf

Revision 1.3  2001/11/08 12:21:59  ahenja
*** empty log message ***

Revision 1.2  2000/03/22 09:03:05  ahenja
Updated with header information.
	
-----------------------------------------------------------------------------*/
#include <stdio.h>
#include <unistd.h>
#include <strings.h>
#include "vhlhdf.h"
#include "read_vhlhdf.h"
#include "write_vhlhdf.h"

static char* ProcessName;
static int hlenc_debug=0;

static void PrintHelp(int all);
static void PrintVersion(void);

int main(int argc, char** argv)
{
   extern int optind,opterr;
   int c,i;

   HL_NodeList* nodelist=NULL;

   initHlHdf();
   debugHlHdf(0);

   ProcessName = strdup(argv[0]);

   opterr=0;

   while((c=getopt(argc,argv,"hdv"))!=EOF) {
      switch(c) {
      case 'h':
	 PrintHelp(1);
	 exit(0);
	 break;
      case 'd':
	 hlenc_debug=1;
	 debugHlHdf(2);
	 break;
      case 'v':
	 PrintVersion();
	 exit(0);
	 break;
      default:
	 PrintVersion();
	 PrintHelp(0);
	 exit(1);
	 break;
      }
   }

   if(argc-1!=optind) {
      PrintHelp(0);
      exit(1);
   }

   if(!(nodelist=readHL_NodeList(argv[optind]))) {
      fprintf(stderr,"Failed to read HDF5 file '%s'\n",argv[optind]);
      goto fail;
   }

   for(i=0;i<nodelist->nNodes;i++) {
      printf("%-40s is ",nodelist->nodes[i]->name);
      switch(nodelist->nodes[i]->type) {
      case ATTRIBUTE_ID:
	 printf("an attribute");
	 break;
      case DATASET_ID:
	 printf("a dataset");
	 break;
      case TYPE_ID:
	 printf("a type");
	 break;
      case GROUP_ID:
	 printf("a group");
	 break;
      default:
	 printf("of an unreckognized type");
	 break;
      }
      printf("\n");
   }

   freeHL_NodeList(nodelist);

   exit(0);
   return 0;
 fail:
   freeHL_NodeList(nodelist);

   exit(1);
   return 1;
}

static void PrintHelp(int all)
{
   fprintf(stderr,"Usage: %s [-hdv] hdffile\n",
	   ProcessName);
   if(!all)
      return;

   fprintf(stderr,"\t[-h]    Prints this help.\n");
   fprintf(stderr,"\t[-d]    Turns on debugging.\n");
   fprintf(stderr,"\t[-v]    Prints the version.\n");
   fprintf(stderr,"\thdffile The name of the HDF5 file that should be listed\n");
}

static void PrintVersion()
{
   fprintf(stderr,"HLLIST: Version 0.1\n");
}
